import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { EC2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../EC2Client";
import { DeleteVpcBlockPublicAccessExclusionRequest, DeleteVpcBlockPublicAccessExclusionResult } from "../models/models_3";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteVpcBlockPublicAccessExclusionCommand}.
 */
export interface DeleteVpcBlockPublicAccessExclusionCommandInput extends DeleteVpcBlockPublicAccessExclusionRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteVpcBlockPublicAccessExclusionCommand}.
 */
export interface DeleteVpcBlockPublicAccessExclusionCommandOutput extends DeleteVpcBlockPublicAccessExclusionResult, __MetadataBearer {
}
declare const DeleteVpcBlockPublicAccessExclusionCommand_base: {
    new (input: DeleteVpcBlockPublicAccessExclusionCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteVpcBlockPublicAccessExclusionCommandInput, DeleteVpcBlockPublicAccessExclusionCommandOutput, EC2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DeleteVpcBlockPublicAccessExclusionCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteVpcBlockPublicAccessExclusionCommandInput, DeleteVpcBlockPublicAccessExclusionCommandOutput, EC2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Delete a VPC Block Public Access (BPA) exclusion. A VPC BPA exclusion is a mode that can be applied to a single VPC or subnet that exempts it from the account’s BPA mode and will allow bidirectional or egress-only access. You can create BPA exclusions for VPCs and subnets even when BPA is not enabled on the account to ensure that there is no traffic disruption to the exclusions when VPC BPA is turned on. To learn more about VPC BPA, see <a href="https://docs.aws.amazon.com/vpc/latest/userguide/security-vpc-bpa.html">Block public access to VPCs and subnets</a> in the <i>Amazon VPC User Guide</i>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, DeleteVpcBlockPublicAccessExclusionCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, DeleteVpcBlockPublicAccessExclusionCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const input = { // DeleteVpcBlockPublicAccessExclusionRequest
 *   DryRun: true || false,
 *   ExclusionId: "STRING_VALUE", // required
 * };
 * const command = new DeleteVpcBlockPublicAccessExclusionCommand(input);
 * const response = await client.send(command);
 * // { // DeleteVpcBlockPublicAccessExclusionResult
 * //   VpcBlockPublicAccessExclusion: { // VpcBlockPublicAccessExclusion
 * //     ExclusionId: "STRING_VALUE",
 * //     InternetGatewayExclusionMode: "allow-bidirectional" || "allow-egress",
 * //     ResourceArn: "STRING_VALUE",
 * //     State: "create-in-progress" || "create-complete" || "create-failed" || "update-in-progress" || "update-complete" || "update-failed" || "delete-in-progress" || "delete-complete" || "disable-in-progress" || "disable-complete",
 * //     Reason: "STRING_VALUE",
 * //     CreationTimestamp: new Date("TIMESTAMP"),
 * //     LastUpdateTimestamp: new Date("TIMESTAMP"),
 * //     DeletionTimestamp: new Date("TIMESTAMP"),
 * //     Tags: [ // TagList
 * //       { // Tag
 * //         Key: "STRING_VALUE",
 * //         Value: "STRING_VALUE",
 * //       },
 * //     ],
 * //   },
 * // };
 *
 * ```
 *
 * @param DeleteVpcBlockPublicAccessExclusionCommandInput - {@link DeleteVpcBlockPublicAccessExclusionCommandInput}
 * @returns {@link DeleteVpcBlockPublicAccessExclusionCommandOutput}
 * @see {@link DeleteVpcBlockPublicAccessExclusionCommandInput} for command's `input` shape.
 * @see {@link DeleteVpcBlockPublicAccessExclusionCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for EC2Client's `config` shape.
 *
 * @throws {@link EC2ServiceException}
 * <p>Base exception class for all service exceptions from EC2 service.</p>
 *
 * @public
 */
export declare class DeleteVpcBlockPublicAccessExclusionCommand extends DeleteVpcBlockPublicAccessExclusionCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteVpcBlockPublicAccessExclusionRequest;
            output: DeleteVpcBlockPublicAccessExclusionResult;
        };
        sdk: {
            input: DeleteVpcBlockPublicAccessExclusionCommandInput;
            output: DeleteVpcBlockPublicAccessExclusionCommandOutput;
        };
    };
}
